@@ -15,6 +15,7 @@ fn entropy() -> Result<()> {
    println!("Entropy: {}",GI(v1.entropy()));
    let v2 = vec![1_u8,2,2,3,3,3,4,4,4,4,3,3,3,3,3,3,2,2,2,2,2]; 
    println!("{:?}",v2);
+   // println!("|v2-v1|: {}",GI(v2.vdistu8(&v1)));
    println!("Entropy: {}",GI(v2.entropy()));
    println!("Joint E: {}",GI(v1.jointentropy(&v2)));
    println!("Dependence: {}\n",GI(v1.dependence(&v2)));
@@ -78,7 +79,7 @@ fn vecf64() -> Result<()> {
 #[test]
 fn vecvec() -> Result<()> { 
    let d = 10_usize;
-   let n = 101_usize;
+   let n = 100_usize;
    println!("testing on a random set of {} points in {} dimensional space",GI(n),GI(d));
    let pt = genvec(d,n,5,17); // random test data 
    let (med,medi,outd,outi) = pt.medoid();
@@ -115,8 +116,8 @@ fn vecvec() -> Result<()> {
    println!("Eccentricities\t{}",eccmed);
    let (_, seccs) = pt.sortedeccs(EPS); 
    // println!("Sorted eccs: {}\n", GV(seccs));
-   let medindx = seccs.binsearch(eccmed.median);
-   println!("Lookup of median of eccs indx: {} value: {}", GI(medindx), GI(seccs[medindx]));
+   let medcnt = seccs.binsearch(eccmed.median);
+   println!("Items smaller or equal to median of eccs: {} last value: {}", GI(medcnt), GI(seccs[medcnt-1]));
    Ok(())
 }
 
